@@ -55,12 +55,27 @@ ENEMY_3_INDX_AT_HOME = 14  # HOME_AREAL_INDEXS[0] - 6 - i * 13 # i = 3
 
 
 class Player:
+    """
+    A class used by the Game class. This class is not needed for normal use
+    """
+
     def __init__(self):
+        """
+        Makes a player with 4 pieces all at the home locations
+        """
         self.pieces = []
         self.number_of_pieces = 4
         self.set_all_pices_to_home()
 
     def other_enemy_pos(self, pos):
+        """
+        Returns the index's the other players has to be in to be in the same location as the one given in pos
+
+        :param pos: The location to check for
+        :type pos: int
+        :return enemy_pos: The locations the enemy's pieces has to be at
+        :rtype enemy_pos: list with 4 int's
+        """
         if pos == 0:
             return [[-1], [-1], [-1], [-1]]
 
@@ -85,6 +100,20 @@ class Player:
         return enemy_pos
 
     def get_enemy_at_pos(self, pos, enemys):
+        """
+        Returns the enemy's and the pieces they have at the given location
+
+        :param pos: The location to check for
+        :type pos: int
+        :param enemys: The lications for the enemy's pieces in a list of 4 lists
+
+        :returns:
+        - enemy_at_pos: The enemy's there are at the location
+        - enemy_pieces_at_pos: The pieces the enemy's has at the location
+        :rtype enemy_at_pos: list
+        :rtype enemy_pieces_at_pos: list of list
+
+        """
         # Get the pos the enemy's has to be at to be at the same pos
         other_enemy_pos_at_pos = self.other_enemy_pos(pos)
         # Check if there is a enemy and how many pieces the enemy has there
@@ -109,6 +138,15 @@ class Player:
         return enemy_at_pos, enemy_pieces_at_pos
 
     def get_pieces_that_can_move(self, dice):
+        """
+        Return the pieces that can move with the given dice
+
+        :param dice: The dice the move will be done with
+        :type dice: int
+        :return: movable_pieces: A list with the pieces that can be moved
+        :rtype movable_pieces: list
+
+        """
         movable_pieces = []
         # Go though all the pieces
         for piece_i, piece_place in enumerate(self.pieces):
@@ -125,6 +163,12 @@ class Player:
         return movable_pieces
 
     def player_winner(self):
+        """
+        Returns rather the player is a winner or not
+
+        :return: winner: A bool that indicate rather the player is a winner or not
+        :rtype winner: bool
+        """
         # Go though all the pieces
         for piece_place in self.pieces:
             # If a piece is not at the goal is not the winner
@@ -134,12 +178,36 @@ class Player:
         return True
 
     def set_pieces(self, pieces):
+        """
+        Sets the players pieces
+
+        :param pieces: The pieces to set the players pieces to
+        """
         self.pieces = pieces.copy()
 
     def get_pieces(self):
+        """
+        Returns the players pieces
+
+        :return pieces: The players pieces
+        :rtype pieces: list
+        """
         return self.pieces.copy()
 
     def move_piece(self, piece, dice, enemys):
+        """
+        Move the players piece the given dice following the game rules. Returns the new locations of the enemy's pieces
+
+        :param piece: The piece to move
+        :type piece: int
+        :param dice: The dice to make the move with
+        :type dice: int
+        :param enemys: The enemy's pieces
+        :type enemys: list with 4 lists each with 4 int's
+        :return enemys: The new locations of the enemy's pieces
+        :rtype enemys: list with 4 lists each with 4 int's
+
+        """
         old_piece_pos = self.pieces[piece]
         new_piece_pos = old_piece_pos + dice
 
@@ -280,6 +348,9 @@ class Player:
         return enemys
 
     def set_all_pices_to_home(self):
+        """
+        Sets all the players pieces to the home index
+        """
         self.pieces = []
         for i in range(self.number_of_pieces):
             self.pieces.append(HOME_INDEX)
